@@ -72,7 +72,7 @@ def is_none(obj: Any, message: str = None):
         raise AssertionError(f'{_message}Object {short(obj)}<{type(obj).__name__}> is not None!')
 
 
-def not_none(obj: Any, message: str = None):
+def is_not_none(obj: Any, message: str = None):
     """
     It checks that the object is not None, the inverse function for is_none.
     :param obj: is the checked object
@@ -152,12 +152,8 @@ def is_positive(actual: Union[int, float, Sequence]):
         if actual <= 0:
             raise AssertionError(f'{actual} is not positive!')
     else:
-        try:
-            len_ = len(actual)
-            if len_ <= 0:
-                raise AssertionError(f'Length of "{short(actual)}"<{type(actual).__name__}> is not positive!')
-        except TypeError:
-            raise TestBrokenException(f'Object "{short(actual)}"<{type(actual).__name__}> has no len!')
+        if _get_length_if_sized(actual) <= 0:
+            raise AssertionError(f'Length of "{short(actual)}"<{type(actual).__name__}> is not positive!')
 
 
 def is_negative(actual: Union[int, float]):
@@ -179,13 +175,20 @@ def is_empty(container: Sized, message: str = None):
     :return: None
     """
     _message = _mess(message)
-    try:
-        length = len(container)
-        if length > 0:
-            raise AssertionError(f'{_message}"{short(container)}"<{type(container).__name__}> is not empty!')
-    except TypeError:
-        raise TestBrokenException(f'"{short(container)}"<{type(container).__name__}> '
-                                  f'has no len and cant be checked for emptiness!')
+    if _get_length_if_sized(container):
+        raise AssertionError(f'{_message}"{short(container)}"<{type(container).__name__}> is not empty!')
+
+
+def is_not_empty(container: Sized, message: str = None):
+    """
+    Function checks the container is NOT empty (len>0)
+    :param message: optional message
+    :param container: any object which has size
+    :return: None
+    """
+    _message = _mess(message)
+    if not _get_length_if_sized(container):
+        raise AssertionError(f'{_message}"{short(container)}"<{type(container).__name__}> is empty!')
 
 
 def __contains_or_not(part, whole, is_contains: bool = True, message: str = None):
@@ -211,6 +214,20 @@ def _mess(message: str) -> str:
     return f'{message}\n' if message else ''
 
 
+def _get_length_if_sized(container: Sized) -> int:
+    """
+    Returns length of container or raise Exception
+    :param container: Sized object
+    :return: length of object
+    :raises: TestBrokenException if object has ho length
+    """
+    try:
+        return len(container)
+    except TypeError:
+        raise TestBrokenException(f'"{short(container)}"<{type(container).__name__}> '
+                                  f'has no len and cant be checked for emptiness!')
+
+
 def _check_argument_is_number(actual, name: str):
     if type(actual) not in (int, float):
         raise TestBrokenException(f"Only int or float types allowed for {name}," +
